@@ -13,6 +13,8 @@
 #include "QXmppUtils.h"
 #include "QXmppUtils_p.h"
 
+#include "StringLiterals.h"
+
 #include <QStringBuilder>
 
 #undef max
@@ -26,7 +28,7 @@ using Manager = QXmppOmemoManager;
 using ManagerPrivate = QXmppOmemoManagerPrivate;
 
 // default label used for the own device
-const auto DEVICE_LABEL = QStringLiteral("QXmpp");
+const auto DEVICE_LABEL = u"QXmpp"_s;
 
 class QXmppOmemoOwnDevicePrivate : public QSharedData
 {
@@ -356,19 +358,19 @@ QXmppTask<bool> Manager::load()
     QXmppPromise<bool> interface;
 
     auto future = d->omemoStorage->allData();
-    future.then(this, [=](QXmppOmemoStorage::OmemoData omemoData) mutable {
+    future.then(this, [=, this](QXmppOmemoStorage::OmemoData omemoData) mutable {
         const auto &optionalOwnDevice = omemoData.ownDevice;
         if (optionalOwnDevice) {
             d->ownDevice = *optionalOwnDevice;
         } else {
-            debug(QStringLiteral("Device could not be loaded because it is not stored"));
+            debug(u"Device could not be loaded because it is not stored"_s);
             interface.finish(false);
             return;
         }
 
         const auto &signedPreKeyPairs = omemoData.signedPreKeyPairs;
         if (signedPreKeyPairs.isEmpty()) {
-            warning(QStringLiteral("Signed Pre keys could not be loaded because none is stored"));
+            warning(u"Signed Pre keys could not be loaded because none is stored"_s);
             interface.finish(false);
             return;
         } else {
@@ -378,7 +380,7 @@ QXmppTask<bool> Manager::load()
 
         const auto &preKeyPairs = omemoData.preKeyPairs;
         if (preKeyPairs.isEmpty()) {
-            warning(QStringLiteral("Pre keys could not be loaded because none is stored"));
+            warning(u"Pre keys could not be loaded because none is stored"_s);
             interface.finish(false);
             return;
         } else {
@@ -407,7 +409,7 @@ QXmppTask<bool> Manager::setUp()
     QXmppPromise<bool> interface;
 
     auto future = d->setUpDeviceId();
-    future.then(this, [=](bool isDeviceIdSetUp) mutable {
+    future.then(this, [=, this](bool isDeviceIdSetUp) mutable {
         if (isDeviceIdSetUp) {
             // The identity key pair in its deserialized form is not stored as a
             // member variable because it is only needed by
@@ -418,9 +420,9 @@ QXmppTask<bool> Manager::setUp()
                 d->updateSignedPreKeyPair(identityKeyPair.get()) &&
                 d->updatePreKeyPairs(PRE_KEY_INITIAL_CREATION_COUNT)) {
                 auto future = d->omemoStorage->setOwnDevice(d->ownDevice);
-                future.then(this, [=]() mutable {
+                future.then(this, [=, this]() mutable {
                     auto future = d->publishOmemoData();
-                    future.then(this, [=](bool isPublished) mutable {
+                    future.then(this, [=, this](bool isPublished) mutable {
                         d->isStarted = isPublished;
                         interface.finish(std::move(isPublished));
                     });
@@ -448,7 +450,7 @@ QXmppTask<QByteArray> Manager::ownKey()
 
 ///
 /// Returns the JIDs of all key owners mapped to the IDs of their keys with
-/// specific trust levels.
+/// specific trust levels except for the own key.
 ///
 /// If no trust levels are passed, all keys are returned.
 ///
@@ -458,7 +460,8 @@ QXmppTask<QByteArray> Manager::ownKey()
 ///
 /// \param trustLevels trust levels of the keys
 ///
-/// \return the key owner JIDs mapped to their keys with specific trust levels
+/// \return the key owner JIDs mapped to their keys with specific trust levels except for the own
+///         key
 ///
 QXmppTask<QHash<QXmpp::TrustLevel, QMultiHash<QString, QByteArray>>> Manager::keys(QXmpp::TrustLevels trustLevels)
 {
@@ -467,7 +470,7 @@ QXmppTask<QHash<QXmpp::TrustLevel, QMultiHash<QString, QByteArray>>> Manager::ke
 
 ///
 /// Returns the IDs of keys mapped to their trust levels for specific key
-/// owners.
+/// owners except for the own key.
 ///
 /// If no trust levels are passed, all keys for jids are returned.
 ///
@@ -478,7 +481,7 @@ QXmppTask<QHash<QXmpp::TrustLevel, QMultiHash<QString, QByteArray>>> Manager::ke
 /// \param jids key owners' bare JIDs
 /// \param trustLevels trust levels of the keys
 ///
-/// \return the key IDs mapped to their trust levels for specific key owners
+/// \return the key IDs mapped to their trust levels for specific key owners except for the own key
 ///
 QXmppTask<QHash<QString, QHash<QByteArray, QXmpp::TrustLevel>>> Manager::keys(const QList<QString> &jids, QXmpp::TrustLevels trustLevels)
 {
@@ -711,7 +714,7 @@ QXmppTask<QVector<QXmppOmemoDevice>> Manager::devices(const QList<QString> &jids
     QXmppPromise<QVector<QXmppOmemoDevice>> interface;
 
     auto future = keys(jids);
-    future.then(this, [=](QHash<QString, QHash<QByteArray, TrustLevel>> keys) mutable {
+    future.then(this, [=, this](QHash<QString, QHash<QByteArray, TrustLevel>> keys) mutable {
         QVector<QXmppOmemoDevice> devices;
 
         for (const auto &jid : jids) {
@@ -760,7 +763,7 @@ QXmppTask<QXmppPubSubManager::Result> Manager::removeContactDevices(const QStrin
     Q_ASSERT_X(jid != d->ownBareJid(), "Removing contact device", "Own JID passed");
 
     auto future = d->unsubscribeFromDeviceList(jid);
-    future.then(this, [=](QXmppPubSubManager::Result result) mutable {
+    future.then(this, [=, this](QXmppPubSubManager::Result result) mutable {
         if (std::holds_alternative<QXmppError>(result)) {
             warning(u"Contact '" + jid + u"' could not be removed because the device list subscription could not be removed");
             interface.finish(std::move(result));
@@ -768,9 +771,9 @@ QXmppTask<QXmppPubSubManager::Result> Manager::removeContactDevices(const QStrin
             d->devices.remove(jid);
 
             auto future = d->omemoStorage->removeDevices(jid);
-            future.then(this, [=]() mutable {
+            future.then(this, [=, this]() mutable {
                 auto future = d->trustManager->removeKeys(ns_omemo_2.toString(), jid);
-                future.then(this, [=]() mutable {
+                future.then(this, [=, this]() mutable {
                     interface.finish(std::move(result));
                     Q_EMIT devicesRemoved(jid);
                 });
@@ -919,6 +922,8 @@ QXmppTask<void> Manager::buildMissingSessions(const QList<QString> &jids)
 /// Existing sessions are reset, which might lead to undecryptable incoming
 /// stanzas until everything is set up again.
 ///
+/// \return whether the action was successful
+///
 QXmppTask<bool> Manager::resetOwnDevice()
 {
     return d->resetOwnDevice();
@@ -941,6 +946,8 @@ QXmppTask<bool> Manager::resetOwnDevice()
 /// Existing sessions are reset, which might lead to undecryptable incoming
 /// stanzas until everything is set up again.
 ///
+/// \return whether the action was successful
+///
 QXmppTask<bool> Manager::resetAll()
 {
     return d->resetAll();
@@ -1020,7 +1027,7 @@ QXmppTask<QXmppE2eeExtension::MessageDecryptResult> QXmppOmemoManager::decryptMe
 {
     if (!d->isStarted) {
         return makeReadyTask<MessageDecryptResult>(QXmppError {
-            QStringLiteral("OMEMO manager must be started before decrypting"),
+            u"OMEMO manager must be started before decrypting"_s,
             SendError::EncryptionError });
     }
 
@@ -1033,7 +1040,7 @@ QXmppTask<QXmppE2eeExtension::MessageDecryptResult> QXmppOmemoManager::decryptMe
             return std::move(*message);
         }
         return QXmppError {
-            QStringLiteral("Couldn't decrypt message"),
+            u"Couldn't decrypt message"_s,
             {}
         };
     });
@@ -1045,7 +1052,7 @@ QXmppTask<QXmppE2eeExtension::IqEncryptResult> Manager::encryptIq(QXmppIq &&iq,
 
     if (!d->isStarted) {
         interface.finish(QXmppError {
-            QStringLiteral("OMEMO manager must be started before encrypting"),
+            u"OMEMO manager must be started before encrypting"_s,
             SendError::EncryptionError });
     } else {
         std::optional<TrustLevels> acceptedTrustLevels;
@@ -1062,7 +1069,7 @@ QXmppTask<QXmppE2eeExtension::IqEncryptResult> Manager::encryptIq(QXmppIq &&iq,
         future.then(this, [=, iq = std::move(iq)](std::optional<QXmppOmemoElement> omemoElement) mutable {
             if (!omemoElement) {
                 interface.finish(QXmppError {
-                    QStringLiteral("OMEMO element could not be created"),
+                    u"OMEMO element could not be created"_s,
                     SendError::EncryptionError });
 
             } else {
@@ -1087,7 +1094,7 @@ QXmppTask<QXmppE2eeExtension::IqDecryptResult> Manager::decryptIq(const QDomElem
     if (!d->isStarted) {
         // TODO: Add decryption queue to avoid this error
         return makeReadyTask<IqDecryptResult>(QXmppError {
-            QStringLiteral("OMEMO manager must be started before decrypting"),
+            u"OMEMO manager must be started before decrypting"_s,
             SendError::EncryptionError });
     }
 
@@ -1098,7 +1105,7 @@ QXmppTask<QXmppE2eeExtension::IqDecryptResult> Manager::decryptIq(const QDomElem
                 return result->iq;
             }
             return QXmppError {
-                QStringLiteral("OMEMO message could not be decrypted"),
+                u"OMEMO message could not be decrypted"_s,
                 SendError::EncryptionError
             };
         });
@@ -1132,21 +1139,21 @@ bool Manager::handleStanza(const QDomElement &stanza)
 
     // TODO: Queue incoming IQs until OMEMO is initialized
     if (!d->isStarted) {
-        warning(QStringLiteral("Couldn't decrypt incoming IQ because the manager isn't initialized yet."));
+        warning(u"Couldn't decrypt incoming IQ because the manager isn't initialized yet."_s);
         return false;
     }
 
-    auto type = stanza.attribute(QStringLiteral("type"));
+    auto type = stanza.attribute(u"type"_s);
     if (type != u"get" && type != u"set") {
         // ignore incoming result and error IQs (they are handled via Client::sendIq())
         return false;
     }
 
-    d->decryptIq(stanza).then(this, [=](auto result) {
+    d->decryptIq(stanza).then(this, [=, this](auto result) {
         if (result) {
             injectIq(result->iq, result->e2eeMetadata);
         } else {
-            warning(QStringLiteral("Could not decrypt incoming OMEMO IQ."));
+            warning(u"Could not decrypt incoming OMEMO IQ."_s);
         }
     });
     return true;
@@ -1233,7 +1240,7 @@ void Manager::onRegistered(QXmppClient *client)
         qFatal("QXmppPubSubManager is not available, it must be added to the client before adding QXmppOmemoManager");
     }
 
-    connect(d->trustManager, &QXmppTrustManager::trustLevelsChanged, this, [=](const QHash<QString, QMultiHash<QString, QByteArray>> &modifiedKeys) {
+    connect(d->trustManager, &QXmppTrustManager::trustLevelsChanged, this, [=, this](const QHash<QString, QMultiHash<QString, QByteArray>> &modifiedKeys) {
         const auto &modifiedOmemoKeys = modifiedKeys.value(ns_omemo_2.toString());
 
         if (!modifiedOmemoKeys.isEmpty()) {
